@@ -3,7 +3,7 @@ App::DBBrowser::From::Subquery;
 
 use warnings;
 use strict;
-use 5.016;
+use 5.014;
 
 use File::Spec::Functions qw( catfile );
 
@@ -11,11 +11,12 @@ use List::MoreUtils qw( any );
 
 use Term::Choose           qw();
 use Term::Choose::LineFold qw( line_fold );
+use Term::Choose::Util     qw( get_term_width );
 use Term::Form::ReadLine   qw();
 
 use App::DBBrowser::Auxil;
 
-my $pf_saved_subqueries = '= ';
+my $pf_saved_subqueries = '- ';
 my $pf_subquery_history = '~ ';
 my $pf_print_history    = '| ';
 
@@ -208,7 +209,7 @@ sub __get_history {
     my ( $sf ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $h_ref = $ax->read_json( $sf->{i}{f_subqueries} ) // {};
-    my $saved_subqueries = $h_ref->{ $sf->{i}{plugin} }{ $sf->{d}{db} } // [];
+    my $saved_subqueries = $h_ref->{ $sf->{i}{driver} }{ $sf->{d}{db} } // [];
     my ( $subquery_history, $print_history ) = $sf->__session_history();
     return $saved_subqueries, $subquery_history, $print_history;
 }
@@ -228,7 +229,7 @@ sub __edit_sq_history_file {
     my ( $sf ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $tc = Term::Choose->new( $sf->{i}{tc_default} );
-    my $plugin = $sf->{i}{plugin};
+    my $driver = $sf->{i}{driver};
     my $db = $sf->{d}{db};
     my @pre = ( undef );
     my ( $add, $edit, $remove ) = ( '- Add', '- Edit', '- Remove' );
@@ -238,10 +239,13 @@ sub __edit_sq_history_file {
     STORED: while ( 1 ) {
         my $top_lines = [ $sf->{d}{db_string}, 'Stored Subqueries:' ];
         my $h_ref = $ax->read_json( $sf->{i}{f_subqueries} ) // {};
-        my $saved_subqueries = $h_ref->{$plugin}{$db} // [];
+        my $saved_subqueries = $h_ref->{$driver}{$db} // [];
         my @tmp_info = (
             @$top_lines,
-            map( line_fold( $_->{name}, { init_tab => '  ', subseq_tab => '    ' } ), @$saved_subqueries ), #
+            map( line_fold(
+                $_->{name}, get_term_width(),
+                { init_tab => '  ', subseq_tab => '    ', join => 1 }
+            ), @$saved_subqueries ), #
             ' '
         );
         my $info = join( "\n", @tmp_info );
@@ -275,10 +279,10 @@ sub __edit_sq_history_file {
         }
         if ( $changed ) {
             if ( @$saved_subqueries ) {
-                $h_ref->{$plugin}{$db} = $saved_subqueries;
+                $h_ref->{$driver}{$db} = $saved_subqueries;
             }
             else {
-                delete $h_ref->{$plugin}{$db};
+                delete $h_ref->{$driver}{$db};
             }
             $ax->write_json( $sf->{i}{f_subqueries}, $h_ref );
             $any_change++;
@@ -301,11 +305,15 @@ sub __add_subqueries {
     while ( 1 ) {
         my @tmp_info = (
             @$top_lines,
-            map( line_fold( $_->{name}, { init_tab => '  ', subseq_tab => '    ' } ), @$saved_subqueries ), #
+            map( line_fold(
+                $_->{name}, get_term_width(),
+                { init_tab => '  ', subseq_tab => '    ', join => 1 }
+            ), @$saved_subqueries ), #
         );
         if ( @$added_sq ) {
-            push @tmp_info, map(
-                line_fold( $_->{name}, { init_tab => $pf_saved_subqueries, subseq_tab => '    ' }
+            push @tmp_info, map( line_fold(
+                $_->{name}, get_term_width(),
+                { init_tab => $pf_saved_subqueries, subseq_tab => '    ', join => 1 }
             ), @$added_sq ); #
         }
         push @tmp_info, ' ';
@@ -343,7 +351,8 @@ sub __add_subqueries {
                     next;
             }
             my $folded_stmt = "\n" . line_fold(
-                'Stmt: ' . $stmt, { init_tab => '', subseq_tab => ' ' x length( 'Stmt: ' ) }
+                'Stmt: ' . $stmt, get_term_width(),
+                { init_tab => '', subseq_tab => ' ' x length( 'Stmt: ' ), join => 1 }
             );
             $info = join( "\n", @tmp_info ) . $folded_stmt;
             # Readline
@@ -394,7 +403,8 @@ sub __edit_subqueries {
         return;
     }
     my $folded_stmt = "\n" . line_fold(
-        'Stmt: ' . $stmt, { init_tab => '', subseq_tab => ' ' x length( 'Stmt: ' ) }
+        'Stmt: ' . $stmt, get_term_width(),
+        { init_tab => '', subseq_tab => ' ' x length( 'Stmt: ' ), join => 1 }
     );
     $info .= $folded_stmt;
     my $default_name;
@@ -447,10 +457,12 @@ sub __remove_subqueries {
        $idx -= @pre;
         my @tmp_prompt = ( '' );
         push @tmp_prompt, line_fold(
-            'Name: ' . $saved_subqueries->[$idx]{name}, { init_tab => '', subseq_tab => ' ' x length( 'Name: ' ) }
+            'Name: ' . $saved_subqueries->[$idx]{name}, get_term_width(),
+            { init_tab => '', subseq_tab => ' ' x length( 'Name: ' ), join => 0 }
         );
         push @tmp_prompt, line_fold(
-            'Stmt: ' . $saved_subqueries->[$idx]{stmt}, { init_tab => '', subseq_tab => ' ' x length( 'Stmt: ' ) }
+            'Stmt: ' . $saved_subqueries->[$idx]{stmt}, get_term_width(),
+            { init_tab => '', subseq_tab => ' ' x length( 'Stmt: ' ), join => 0 }
         );
         push @tmp_prompt, '', $prompt;
         my $ok = $tc->choose(
