@@ -302,10 +302,10 @@ sub set_options {
             elsif ( $opt eq '_e_union' ) {
                 my $prompt = 'Extend Union Menu:';
                 my $sub_menu = [
-                    [ 'u_derived',     "- Add Subquery", [ $no, $yes ] ],
-                    [ 'u_cte',         "- Add Cte",      [ $no, $yes ] ],
-                    [ 'u_where',       "- Where",        [ $no, $yes ] ],
-                    [ 'u_parentheses', "- Parentheses",  [ $no, $yes ] ],
+                    [ 'u_derived',     "- Add Subquery",   [ $no, $yes ] ],
+                    [ 'u_cte',         "- Add Cte",        [ $no, $yes ] ],
+                    [ 'u_edit_stmt',   "- Edit Statement", [ $no, $yes ] ],
+                    [ 'u_parentheses', "- Parentheses",    [ $no, $yes ] ],
                 ];
                 $sf->__settings_menu_wrap( $section, $sub_menu, $prompt );
             }
