@@ -45,7 +45,7 @@ sub __choose_a_column {
             # from 'window_function': to avoid window function in window function
             my $complex_col = $ext->column(
                 $sql, $clause, $r_data,
-                { from =>'window_function' }
+                { from => 'window_function' }
             );
             if ( ! defined $complex_col ) {
                 next;
@@ -58,32 +58,77 @@ sub __choose_a_column {
 
 
 sub __get_win_func_stmt {
-    my ( $sf, $win_func_data ) = @_;
-    my $win_func_stmt = $win_func_data->{func};
-    $win_func_stmt .= sprintf '(%s)', $win_func_data->{args_str} // '';
-    my @win_definition;
-    for my $stmt ( qw(partition_by_stmt order_by_stmt) ) {
-        if ( length $win_func_data->{$stmt} ) {
-            push @win_definition, $win_func_data->{$stmt};
+    my ( $sf, $win_data, $placeholder ) = @_;
+    $placeholder //= '';
+    my @parts;
+    my $win_stmt = $win_data->{func};
+    $win_stmt .= '(' . $win_data->{args_str} // '';
+    if ( $placeholder eq 'args_str' ) {
+        push @parts, $win_stmt;
+        $win_stmt = '';
+    }
+    $win_stmt .= ') OVER (';
+    if ( length $win_data->{partition_by_stmt} ) {
+        $win_stmt .= $win_data->{partition_by_stmt} . " ";
+    }
+    if ( $placeholder eq 'partition_by_stmt' ) {
+        push @parts, $win_stmt;
+        $win_stmt = '';
+    }
+    if ( length $win_data->{order_by_stmt} ) {
+        $win_stmt .= $win_data->{order_by_stmt} . " ";
+    }
+    if ( $placeholder eq 'order_by_stmt' ) {
+        push @parts, $win_stmt;
+        $win_stmt = '';
+    }
+    if ( length $win_data->{frame_mode} ) {
+        $win_stmt .= $win_data->{frame_mode} . " ";
+        if ( length $win_data->{frame_start} || $placeholder eq 'frame_start' ) {
+            if ( length $win_data->{frame_end} || $placeholder eq 'frame_end' ) {
+                $win_stmt .= "BETWEEN ";
+            }
+            if ( length $win_data->{frame_start} ) {
+                $win_stmt .= $win_data->{frame_start} . " ";
+            }
+            if ( $placeholder eq 'frame_start' ) {
+                push @parts, $win_stmt;
+                $win_stmt = '';
+            }
+        }
+        if ( length $win_data->{frame_end} || $placeholder eq 'frame_end' ) {
+            if ( length $win_data->{frame_start} || $placeholder eq 'frame_start' ) {
+                $win_stmt .= "AND ";
+            }
+            if ( length $win_data->{frame_end} ) {
+                $win_stmt .= $win_data->{frame_end} . " ";
+            }
+            if ( $placeholder eq 'frame_end' ) {
+                push @parts, $win_stmt;
+                $win_stmt = '';
+            }
+        }
+        if ( length $win_data->{frame_exclusion} ) {
+            $win_stmt .= $win_data->{frame_exclusion};
+        }
+        if ( $placeholder eq 'frame_exclusion' ) {
+            push @parts, $win_stmt;
+            $win_stmt = '';
         }
     }
-    if ( length $win_func_data->{frame_mode} ) {
-        push @win_definition, $win_func_data->{frame_mode};
-        if ( length $win_func_data->{frame_start} && length $win_func_data->{frame_end} ) {
-            push @win_definition,  "BETWEEN " . $win_func_data->{frame_start} . " AND " . $win_func_data->{frame_end};
-        }
-        elsif ( length $win_func_data->{frame_start} ) {
-            push @win_definition, $win_func_data->{frame_start};
-        }
-        elsif ( length $win_func_data->{frame_end} ) {
-            push @win_definition, $win_func_data->{frame_end};
-        }
-        if ( length $win_func_data->{frame_exclusion} ) {
-            push @win_definition, $win_func_data->{frame_exclusion};
-        }
+    if ( $placeholder eq 'frame_mode' ) {
+        push @parts, $win_stmt;
+        $win_stmt = '';
     }
-    $win_func_stmt .= sprintf ' OVER (%s)', join( ' ',  @win_definition ) // '';
-    return $win_func_stmt;
+    if ( ! $placeholder ) {
+        push @parts, $win_stmt;
+        $win_stmt = '';
+    }
+    $parts[0] =~ s/\s+\z//;
+    $win_stmt =~ s/\s+\z//;
+    $win_stmt .= ')';
+    push @parts, $win_stmt;
+    return @parts;
 }
 
 
@@ -118,7 +163,7 @@ sub window_function {
     my $old_idx_wf = 1;
 
     WINDOW_FUNCTION: while( 1 ) {
-        my $win_func_data = {};
+        my $win_data = {};
         $r_data->[-1] = [ 'win' ];
         my $info = $info_sql . $ext->nested_func_info( $r_data );
         my @pre = ( $hidden, undef );
@@ -145,15 +190,15 @@ sub window_function {
             next WINDOW_FUNCTION;
         }
         my $func = $functions[$idx_wf-@pre];
-        $win_func_data->{func} = $func;
-        $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+        $win_data->{func} = $func;
 
         COLUMN: while ( 1 ) {
-            $win_func_data->{args_str} = '';
+            $win_data->{args_str} = '';
+            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data, 'args_str' ) ];
             my $col;
             if ( $func =~ /^$rx_func_count_all\z/i ) {
                 $col = '*';
-                $win_func_data->{func} = $func =~ s/\*\z//r;
+                $win_data->{func} = $func =~ s/\*\z//r;
             }
             elsif ( $func =~ /^(?:$rx_func_no_col)\z/i ) {
                 $col = '';
@@ -162,7 +207,7 @@ sub window_function {
                 # Readline
                 $col = $ext->argument(
                     $sql, $clause, $r_data,
-                    { history => undef, prompt => 'n = ', is_numeric => 1 }
+                    { history => undef, prompt => 'n = ', is_numeric => 1, from => 'window_function' }
                 );
                 if ( ! length $col || $col eq "''" ) {
                     next WINDOW_FUNCTION;
@@ -174,27 +219,27 @@ sub window_function {
                     next WINDOW_FUNCTION;
                 }
             }
-            $win_func_data->{args_str} = $col;
-            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+            $win_data->{args_str} = $col;
             if ( $func =~ /^(?:$rx_func_with_offset)\z/i ) {
+                $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data, 'args_str' ) ];
                 # Readline
                 my $offset = $ext->argument(
                     $sql, $clause, $r_data,
-                    { history => undef, prompt => 'offset: ', is_numeric => 1 }
+                    { prompt => 'offset: ', is_numeric => 1 }
                 );
                 if ( length $offset && $offset ne "''" ) {
-                    $win_func_data->{args_str} .= ',' . $offset;
-                    $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+                    $win_data->{args_str} .= ',' . $offset;
                     if ( $func =~ /^(?:$rx_func_with_offset_and_default)\z/i ) {
-                        my $is_numeric = $ax->is_numeric_datatype( $sql, $col );
+                        $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data, 'args_str' ) ];
+                        my $is_numeric = $ax->is_numeric( $sql, $col );
                         # Readline
                         my $default_value = $ext->argument(
                             $sql, $clause, $r_data,
-                            { history => undef, prompt => 'default: ', is_numeric => $is_numeric }
+                            { prompt => 'default: ', is_numeric => $is_numeric, from => 'window_function' }
                         );
                         if ( length $default_value && $default_value ne "''" ) {
-                            $win_func_data->{args_str} .= ',' . $default_value;
-                            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+                            $win_data->{args_str} .= ',' . $default_value;
+                            #$r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data ) ];
                         }
                     }
                 }
@@ -205,6 +250,7 @@ sub window_function {
                 my ( $partition_by, $order_by, $frame_clause ) = ( '- Partition by', '- Order by', '- Frame clause' );
                 my @pre = ( undef, $sf->{i}{confirm} );
                 my $menu = [ @pre, $partition_by, $order_by, $frame_clause ];
+                $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data ) ];
                 my $info = $info_sql . $ext->nested_func_info( $r_data );
                 # Choose
                 my $idx_wd = $tc->choose(
@@ -213,9 +259,8 @@ sub window_function {
                       undef => $sf->{i}{back} }
                 );
                 if ( ! defined $idx_wd || ! defined $menu->[$idx_wd] ) {
-                    if ( $win_func_data->{partition_by_stmt} || $win_func_data->{order_by_stmt} || $win_func_data->{frame_mode} ) {
-                        $win_func_data = { func => $win_func_data->{func}, args_str => $win_func_data->{args_str} };
-                        $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+                    if ( $win_data->{partition_by_stmt} || $win_data->{order_by_stmt} || $win_data->{frame_mode} ) {
+                        $win_data = { func => $win_data->{func}, args_str => $win_data->{args_str} };
                         next WINDOW_DEFINITION;
                     }
                     if ( $func =~ /^(?:$rx_func_count_all|$rx_func_no_col)\z/ ) {
@@ -233,17 +278,17 @@ sub window_function {
                 my $wd = $menu->[$idx_wd];
                 if ( $wd eq $sf->{i}{confirm} ) {
                     pop @$r_data;
-                    my $win_func_stmt = $sf->__get_win_func_stmt( $win_func_data );
-                    return $win_func_stmt;
+                    my @parts = $sf->__get_win_func_stmt( $win_data );
+                    return join '', @parts;
                 }
                 elsif ( $wd eq $partition_by ) {
-                    $sf->__add_partition_by( $sql, $clause, $cols, $r_data, $win_func_data );
+                    $sf->__add_partition_by( $sql, $clause, $cols, $r_data, $win_data );
                 }
                 elsif ( $wd eq $order_by ) {
-                    $sf->__add_order_by( $sql, $clause, $cols, $r_data, $win_func_data );
+                    $sf->__add_order_by( $sql, $clause, $cols, $r_data, $win_data );
                 }
                 elsif ( $wd eq $frame_clause ) {
-                    $sf->__add_frame_clause( $sql, $clause, $r_data, $win_func_data );
+                    $sf->__add_frame_clause( $sql, $clause, $r_data, $win_data );
                 }
             }
         }
@@ -252,11 +297,11 @@ sub window_function {
 
 
 sub __add_partition_by {
-    my ( $sf, $sql, $clause, $cols, $r_data, $win_func_data ) = @_;
+    my ( $sf, $sql, $clause, $cols, $r_data, $win_data ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $ext = App::DBBrowser::Table::Extensions->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $tc = Term::Choose->new( $sf->{i}{tc_default} );
-    $win_func_data->{partition_by_cols} //= [];
+    $win_data->{partition_by_cols} //= [];
     my @pre = ( undef, $sf->{i}{ok} );
     if ( $sf->{o}{enable}{extended_cols} ) {
         push @pre, $sf->{i}{menu_addition};
@@ -265,40 +310,39 @@ sub __add_partition_by {
     my $info_sql = $ax->get_sql_info( $sql );
 
     PARTITION_BY: while ( 1 ) {
-        if ( @{$win_func_data->{partition_by_cols}} ) {
-            $win_func_data->{partition_by_stmt} = "PARTITION BY " . join ',', @{$win_func_data->{partition_by_cols}};
+        if ( @{$win_data->{partition_by_cols}} ) {
+            $win_data->{partition_by_stmt} = "PARTITION BY " . join ',', @{$win_data->{partition_by_cols}};
         }
         else {
-            $win_func_data->{partition_by_stmt} = "PARTITION BY";
+            $win_data->{partition_by_stmt} = "PARTITION BY";
         }
-        $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+        $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data, 'partition_by_stmt' ) ];
         my $info = $info_sql . $ext->nested_func_info( $r_data );
+        my $prompt = 'Partition by:';
         # Choose
         my @idx = $tc->choose(
             $menu,
             { %{$sf->{i}{lyt_h}}, info => $info, meta_items => [ 0 .. $#pre - 1 ], no_spacebar => [ $#pre ],
-              include_highlighted => 2, index => 1, prompt => 'Columns:' }
+              include_highlighted => 2, index => 1, prompt => $prompt }
         );
         $ax->print_sql_info( $info );
         if ( ! $idx[0] ) {
-            if ( @{$win_func_data->{partition_by_cols}} ) {
-                pop @{$win_func_data->{partition_by_cols}};
+            if ( @{$win_data->{partition_by_cols}} ) {
+                pop @{$win_data->{partition_by_cols}};
                 next PARTITION_BY;
             }
-            delete $win_func_data->{partition_by_stmt};
-            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+            delete $win_data->{partition_by_stmt};
             return;
         }
         elsif ( $menu->[$idx[0]] eq $sf->{i}{ok} ) {
             shift @idx;
-            push @{$win_func_data->{partition_by_cols}}, @{$menu}[@idx];
-            if ( ! @{$win_func_data->{partition_by_cols}} ) {
-                delete $win_func_data->{partition_by_stmt};
+            push @{$win_data->{partition_by_cols}}, @{$menu}[@idx];
+            if ( ! @{$win_data->{partition_by_cols}} ) {
+                delete $win_data->{partition_by_stmt};
             }
             else {
-                $win_func_data->{partition_by_stmt} = "PARTITION BY " . join ',', @{$win_func_data->{partition_by_cols}};
+                $win_data->{partition_by_stmt} = "PARTITION BY " . join ',', @{$win_data->{partition_by_cols}};
             }
-            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
             return 1;
         }
         elsif ( $menu->[$idx[0]] eq $sf->{i}{menu_addition} ) {
@@ -308,21 +352,21 @@ sub __add_partition_by {
                 { from => 'window_function' }
             );
             if ( defined $complex_column ) {
-                push @{$win_func_data->{partition_by_cols}}, $complex_column;
+                push @{$win_data->{partition_by_cols}}, $complex_column;
             }
             next PARTITION_BY;
         }
-        push @{$win_func_data->{partition_by_cols}}, @{$menu}[@idx];
+        push @{$win_data->{partition_by_cols}}, @{$menu}[@idx];
     }
 }
 
 
 sub __add_order_by {
-    my ( $sf, $sql, $clause, $cols, $r_data, $win_func_data ) = @_;
+    my ( $sf, $sql, $clause, $cols, $r_data, $win_data ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $ext = App::DBBrowser::Table::Extensions->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $tc = Term::Choose->new( $sf->{i}{tc_default} );
-    $win_func_data->{order_by_cols} //= [];
+    $win_data->{order_by_cols} //= [];
     my @pre = ( undef, $sf->{i}{ok} );
     if ( $sf->{o}{enable}{extended_cols} ) {
         push @pre, $sf->{i}{menu_addition};
@@ -330,37 +374,36 @@ sub __add_order_by {
     my $info_sql = $ax->get_sql_info( $sql );
 
     ORDER_BY: while ( 1 ) {
-        if ( @{$win_func_data->{order_by_cols}} ) {
-            $win_func_data->{order_by_stmt} = "ORDER BY " . join ',', @{$win_func_data->{order_by_cols}};
+        if ( @{$win_data->{order_by_cols}} ) {
+            $win_data->{order_by_stmt} = "ORDER BY " . join ',', @{$win_data->{order_by_cols}};
         }
         else {
-            $win_func_data->{order_by_stmt} = "ORDER BY";
+            $win_data->{order_by_stmt} = "ORDER BY";
         }
-        $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+        $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data, 'order_by_stmt' ) ];
         my $info = $info_sql . $ext->nested_func_info( $r_data );
+        my $prompt = 'Order by:';
         # Choose
         my $col = $tc->choose(
             [ @pre, @$cols ],
-            { %{$sf->{i}{lyt_h}}, info => $info, prompt => 'Column:' }
+            { %{$sf->{i}{lyt_h}}, info => $info, prompt => $prompt }
         );
         $ax->print_sql_info( $info );
         if ( ! defined $col ) {
-            if ( @{$win_func_data->{order_by_cols}} ) {
-                pop @{$win_func_data->{order_by_cols}};
+            if ( @{$win_data->{order_by_cols}} ) {
+                pop @{$win_data->{order_by_cols}};
                 next ORDER_BY;
             }
-            delete $win_func_data->{order_by_stmt};
-            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+            delete $win_data->{order_by_stmt};
             return
         }
         if ( $col eq $sf->{i}{ok} ) {
-            if ( ! @{$win_func_data->{order_by_cols}} ) {
-                delete $win_func_data->{order_by_stmt};
+            if ( ! @{$win_data->{order_by_cols}} ) {
+                delete $win_data->{order_by_stmt};
             }
             else {
-                $win_func_data->{order_by_stmt} = "ORDER BY " . join ',', @{$win_func_data->{order_by_cols}};
+                $win_data->{order_by_stmt} = "ORDER BY " . join ',', @{$win_data->{order_by_cols}};
             }
-            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
             return 1;
         }
         elsif ( $col eq $sf->{i}{menu_addition} ) {
@@ -374,9 +417,9 @@ sub __add_order_by {
             }
             $col = $complex_column;
         }
-        push @{$win_func_data->{order_by_cols}}, $col;
-        $win_func_data->{order_by_stmt} = "ORDER BY " . join ',', @{$win_func_data->{order_by_cols}};
-        $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+        push @{$win_data->{order_by_cols}}, $col;
+        $win_data->{order_by_stmt} = "ORDER BY " . join ',', @{$win_data->{order_by_cols}};
+        $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data, 'order_by_stmt' ) ];
         $info = $info_sql . $ext->nested_func_info( $r_data );
         # Choose
         my $direction = $tc->choose(
@@ -385,18 +428,18 @@ sub __add_order_by {
         );
         $ax->print_sql_info( $info );
         if ( ! defined $direction ){
-            pop @{$win_func_data->{order_by_cols}};
+            pop @{$win_data->{order_by_cols}};
             next ORDER_BY;
         }
         else {
-            $win_func_data->{order_by_cols}[-1] .= ' ' . $direction;
+            $win_data->{order_by_cols}[-1] .= ' ' . $direction;
         }
     }
 }
 
 
 sub __add_frame_clause {
-    my ( $sf, $sql, $clause, $r_data, $win_func_data ) = @_;
+    my ( $sf, $sql, $clause, $r_data, $win_data ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $ext = App::DBBrowser::Table::Extensions->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $tc = Term::Choose->new( $sf->{i}{tc_default} );
@@ -404,6 +447,9 @@ sub __add_frame_clause {
     if ( $sf->{i}{driver} =~ /^(?:SQLite|Pg|Oracle)\z/ ) {
         push @frame_clause_modes, 'GROUPS';
     }
+    if ( ! length $win_data->{frame_mode} ) {
+        $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data, 'frame_mode' ) ];
+    }
     my $info_sql = $ax->get_sql_info( $sql );
     my $old_idx_fc = 0;
 
@@ -428,33 +474,32 @@ sub __add_frame_clause {
             $old_idx_fc = $idx_fc;
         }
         my $frame_mode = $frame_clause_modes[$idx_fc-@pre];
-        $win_func_data->{frame_mode} = $frame_mode;
-        $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+        $win_data->{frame_mode} = $frame_mode;
         my $old_idx_fe = 0;
 
         FRAME_END_AND_EXCLUSION: while ( 1 ) {
-            my $confirm = 'Confirm';
+            my $confirm = $sf->{i}{confirm};
+            my $back = $sf->{i}{back};
             my @pre = ( undef, $confirm );
             my ( $frame_start, $frame_end, $frame_exclusion ) = ( '- Add Frame start', '- Add Frame end', '- Add Frame exclusion' );
             my $menu = [ @pre, $frame_start, $frame_end ];
             if ( $sf->{i}{driver} =~ /^(?:SQLite|Pg|Oracle)\z/ ) {
                 push @$menu, $frame_exclusion;
             }
-            my $info = $info_sql . "\n" . $sf->__get_win_func_stmt( $win_func_data );
+            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data, 'frame_mode' ) ];
+            my $info = $info_sql . $ext->nested_func_info( $r_data );
             # Choose
             my $idx_fe = $tc->choose(
                 $menu,
-                { %{$sf->{i}{lyt_v}}, info => $info, index => 1, default => $old_idx_fe, prompt => 'Frame clause:', undef => 'Back' }
+                { %{$sf->{i}{lyt_v}}, info => $info, index => 1, default => $old_idx_fe, prompt => 'Frame clause:', undef => $back }
             );
             $ax->print_sql_info( $info );
             if ( ! defined $idx_fe || ! defined $menu->[$idx_fe] ) {
-                if ( $win_func_data->{frame_start} || $win_func_data->{frame_end} || $win_func_data->{frame_exclusion} ) {
-                    delete @{$win_func_data}{qw(frame_start frame_end frame_exclusion)};
-                    $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+                if ( $win_data->{frame_start} || $win_data->{frame_end} || $win_data->{frame_exclusion} ) {
+                    delete @{$win_data}{qw(frame_start frame_end frame_exclusion)};
                     next FRAME_END_AND_EXCLUSION;
                 }
-                delete $win_func_data->{frame_mode};
-                $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+                delete $win_data->{frame_mode};
                 next FRAME_CLAUSE;
             }
             if ( $sf->{o}{G}{menu_memory} ) {
@@ -469,13 +514,13 @@ sub __add_frame_clause {
                 return 1;
             }
             if ( $choice eq $frame_start ) {
-                $sf->__add_frame_start_or_end( $sql, $clause, $r_data, $win_func_data, 'frame_start' );
+                $sf->__add_frame_start_or_end( $sql, $clause, $r_data, $win_data, 'frame_start' );
             }
             elsif ( $choice eq $frame_end ) {
-                $sf->__add_frame_start_or_end( $sql, $clause, $r_data, $win_func_data, 'frame_end' );
+                $sf->__add_frame_start_or_end( $sql, $clause, $r_data, $win_data, 'frame_end' );
             }
             else {
-                $sf->__add_frame_exclusion( $sql, $r_data, $win_func_data );
+                $sf->__add_frame_exclusion( $sql, $r_data, $win_data );
             }
         }
     }
@@ -483,7 +528,7 @@ sub __add_frame_clause {
 
 
 sub __add_frame_start_or_end {
-    my ( $sf, $sql, $clause, $r_data, $win_func_data, $pos ) = @_;
+    my ( $sf, $sql, $clause, $r_data, $win_data, $pos ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $ext = App::DBBrowser::Table::Extensions->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $tc = Term::Choose->new( $sf->{i}{tc_default} );
@@ -496,12 +541,18 @@ sub __add_frame_start_or_end {
         @frame_point_types = ( 'n PRECEDING', 'CURRENT ROW', 'n FOLLOWING', 'UNBOUNDED FOLLOWING' );
         $prompt = 'Frame end:';
     }
-    my $confirm = '-OK-';
-    my @pre = ( undef, $confirm );
     my $info_sql = $ax->get_sql_info( $sql );
 
     FRAME_START: while ( 1 ) {
+        if ( ! length $win_data->{$pos} ) {
+            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data, $pos ) ];
+        }
+        else {
+            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data ) ];
+        }
         my $info = $info_sql . $ext->nested_func_info( $r_data );
+        my $confirm = $sf->{i}{ok};
+        my @pre = ( undef, $confirm );
         my $menu = [ @pre, map( '- ' . $_, @frame_point_types ) ];
         # Choose
         my $point = $tc->choose(
@@ -510,8 +561,7 @@ sub __add_frame_start_or_end {
         );
         $ax->print_sql_info( $info );
         if ( ! defined $point ) {
-            delete $win_func_data->{$pos};
-            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+            delete $win_data->{$pos};
             return;
         }
         elsif ( $point eq $confirm ) {
@@ -520,21 +570,19 @@ sub __add_frame_start_or_end {
         else {
             my $ext = App::DBBrowser::Table::Extensions->new( $sf->{i}, $sf->{o}, $sf->{d} );
             $point =~ s/-\s//;
-            $win_func_data->{$pos} = $point;
-            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+            $win_data->{$pos} = $point;
+            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data ) ];
             if ( $point =~ /^n / ) {
                 my $offset = $ext->argument(
                     $sql, $clause, $r_data,
                     { history => undef, prompt => 'n = ', is_numeric => 1 }
                 );
                 if ( ! length $offset || $offset eq "''" ) {
-                    delete $win_func_data->{$pos};
-                    $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+                    delete $win_data->{$pos};
                     next FRAME_START;
                 }
                 $point =~ s/^n/$offset/;
-                $win_func_data->{$pos} = $point;
-                $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+                $win_data->{$pos} = $point;
             }
         }
     }
@@ -542,17 +590,24 @@ sub __add_frame_start_or_end {
 
 
 sub __add_frame_exclusion {
-    my ( $sf, $sql, $r_data, $win_func_data ) = @_;
+    my ( $sf, $sql, $r_data, $win_data ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $ext = App::DBBrowser::Table::Extensions->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $tc = Term::Choose->new( $sf->{i}{tc_default} );
     my @exclusion_types = ( 'EXCLUDE CURRENT ROW', 'EXCLUDE GROUP', 'EXCLUDE TIES', 'EXCLUDE NO OTHERS' );
-    my $confirm = '-OK-';
-    my @pre = ( undef, $confirm );
-    my $menu = [ @pre, map( '- ' . $_, @exclusion_types ) ];
+    my $info_sql = $ax->get_sql_info( $sql );
 
     FRAME_EXCLUSION: while ( 1 ) {
-        my $info = $ax->get_sql_info( $sql ) . $ext->nested_func_info( $r_data );
+        if ( ! length $win_data->{frame_exclusion} ) {
+            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data, 'frame_exclusion' ) ];
+        }
+        else {
+            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_data ) ];
+        }
+        my $info = $info_sql . $ext->nested_func_info( $r_data );
+        my $confirm = $sf->{i}{ok};
+        my @pre = ( undef, $confirm );
+        my $menu = [ @pre, map( '- ' . $_, @exclusion_types ) ];
         # Choose
         my $frame_exclusion = $tc->choose(
             $menu,
@@ -560,8 +615,7 @@ sub __add_frame_exclusion {
         );
         $ax->print_sql_info( $info );
         if ( ! defined $frame_exclusion ) {
-            delete $win_func_data->{frame_exclusion};
-            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+            delete $win_data->{frame_exclusion};
             return;
         }
         elsif ( $frame_exclusion eq $confirm ) {
@@ -569,8 +623,7 @@ sub __add_frame_exclusion {
         }
         else {
             $frame_exclusion =~ s/^-\s//;
-            $win_func_data->{frame_exclusion} = $frame_exclusion;
-            $r_data->[-1] = [ 'win', $sf->__get_win_func_stmt( $win_func_data ) ];
+            $win_data->{frame_exclusion} = $frame_exclusion;
         }
     }
 }
