@@ -3,7 +3,7 @@ App::DBBrowser::Table::Substatement;
 
 use warnings;
 use strict;
-use 5.016;
+use 5.014;
 
 use List::MoreUtils qw( any uniq );
 
@@ -306,9 +306,6 @@ sub group_by {
                 #$sql->{having_stmt} = '';
                 $sql->{aggregate_mode} = 0;
             }
-            elsif ( ! @{$sql->{selected_cols}} ) {
-                $sql->{aggregate_mode} = 0;
-            }
             return;
         }
         if ( $menu->[$idx[0]] eq $sf->{i}{ok} ) {
@@ -500,7 +497,7 @@ sub offset {
 
 sub __limit_and_offset_variables {
     my ( $sf ) = @_;
-    my $use_limit = $sf->{i}{driver} =~ /^(?:SQLite|mysql|MariaDB|Pg|DuckDB|Informix)\z/ ? 1 : 0;
+    my $use_limit = $sf->{i}{driver} =~ /^(?:SQLite|mysql|MariaDB|Pg|Informix)\z/ ? 1 : 0;
     my $max_digits = 7;
     return $use_limit, $max_digits;
 }
